@@ -5,14 +5,13 @@ use utf8;
 #use aliased 'PGXN::Site::Request';
 use Plack::Request;
 use Plack::Response;
-use PGXN::Site::Locale;
 use PGXN::Site::Templates;
 use HTML::TagCloud;
 use Encode;
 use WWW::PGXN;
 use List::MoreUtils qw(any);
 use namespace::autoclean;
-our $VERSION = v0.21.0;
+our $VERSION = v0.22.0;
 
 Template::Declare->init( dispatch_to => ['PGXN::Site::Templates'] );
 
@@ -61,6 +60,7 @@ sub render {
     my ($self, $template, $p) = @_;
     my $req = $p->{req} ||= Plack::Request->new($p->{env});
     my $res = $req->new_response($p->{code} || 200);
+    $p->{vars}{base_url} = $self->base_url;
     my $body = encode_utf8 +Template::Declare->show($template, $p->{req}, $p->{vars});
     $res->body($body);
     $res->content_length(length $body);
@@ -80,18 +80,23 @@ sub missing {
     $self->render('/notfound', { env => $env, code => $code_for{notfound} });
 }
 
-sub home {
-    my $self  = shift;
+sub _cloud {
+    my $self = shift;
     my $cloud = HTML::TagCloud->new(levels => 12);
     my $tags  = $self->api->get_stats('tag');
     $cloud->add($_->{tag}, "/tag/$_->{tag}/", $_->{dists})
         for grep { $_->{tag} = lc $_->{tag} } @{ $tags->{popular} };
+    return $cloud;
+}
+
+sub home {
+    my $self  = shift;
     my $dists = $self->api->get_stats('dist')->{recent};
     splice @{ $dists }, 5;
     $self->render('/home', {
         env => shift,
         vars => {
-            cloud => $cloud,
+            cloud => _cloud($self),
             dists => $dists,
         },
     });
@@ -161,6 +166,7 @@ sub distribution {
         dist      => $dist,
         api_url   => $self->api_url,
         dist_name => $dist->{name} . ($version ? " $version" : ''),
+        user      => $self->api->get_user($dist->user),
     }});
 }
 
@@ -180,6 +186,7 @@ sub document {
         body      => $doc,
         dist_uri  => $dist_uri,
         dist_name => $dist_name,
+        user      => $self->api->get_user($dist->user),
     }});
 }
 
@@ -188,10 +195,9 @@ sub user {
     my $user = $self->api->get_user($nick) or return $self->missing($env);
 
     $self->render('/user', { env => $env, vars => {
-        user     => $user,
-        api      => $self->api,
-        api_url  => $self->api_url,
-        base_url => $self->base_url,
+        user    => $user,
+        api     => $self->api,
+        api_url => $self->api_url,
     }});
 }
 
@@ -227,6 +233,14 @@ sub users {
     }});
 }
 
+sub tags {
+    my $self = shift;
+    $self->render('/tags', {
+        env  => shift,
+        vars => { cloud => _cloud($self) },
+    });
+}
+
 sub tag {
     my ($self, $env, $tag) = @_;
     $tag = $self->api->get_tag($tag) or return $self->missing($env);
@@ -502,6 +516,12 @@ Displays the HTML for the user page.
 
 Displays the HTML for the users search page.
 
+=head3 C<tags>
+
+  PGXN::Site::Controller->tags($env);
+
+Displays the HTML for the tags page, including search form and tag cloud.
+
 =head3 C<tag>
 
   PGXN::Site::Controller->tag($env);
