@@ -6,7 +6,7 @@ use PGXN::Site::Controller;
 use Router::Resource;
 use Plack::Builder;
 use Plack::App::File;
-our $VERSION = v0.21.0;
+our $VERSION = v0.22.0;
 
 sub app {
     my $class = shift;
@@ -55,6 +55,11 @@ sub app {
             };
         };
 
+        # /tags
+        resource qr{^/tags/?$} => sub {
+            GET { $controller->tags(shift) };
+        };
+
         # /tag/{tag}/
         resource qr{/tag/([^/]+)/?$} => sub {
             GET {
